pub struct TransformedSubAsset<'a, A>where
A: Asset,{ /* private fields */ }Expand description
A labeled sub-asset of TransformedAsset
Implementations
Sourceimpl<'a, A> TransformedSubAsset<'a, A>where
A: Asset,
impl<'a, A> TransformedSubAsset<'a, A>where
A: Asset,
Sourcepub fn from_loaded(
asset: &'a mut ErasedLoadedAsset,
) -> Option<TransformedSubAsset<'a, A>>
pub fn from_loaded( asset: &'a mut ErasedLoadedAsset, ) -> Option<TransformedSubAsset<'a, A>>
Creates a new TransformedSubAsset from asset if its internal value matches A.
Sourcepub fn get_labeled<B, Q>(
&mut self,
label: &Q,
) -> Option<TransformedSubAsset<'_, B>>
pub fn get_labeled<B, Q>( &mut self, label: &Q, ) -> Option<TransformedSubAsset<'_, B>>
Returns the labeled asset, if it exists and matches this type.
Sourcepub fn get_erased_labeled<Q>(&self, label: &Q) -> Option<&ErasedLoadedAsset>
pub fn get_erased_labeled<Q>(&self, label: &Q) -> Option<&ErasedLoadedAsset>
Returns the type-erased labeled asset, if it exists.
Sourcepub fn get_labeled_by_id<B>(
&mut self,
id: impl Into<AssetId<B>>,
) -> Option<TransformedSubAsset<'_, B>>where
B: Asset,
pub fn get_labeled_by_id<B>(
&mut self,
id: impl Into<AssetId<B>>,
) -> Option<TransformedSubAsset<'_, B>>where
B: Asset,
Returns the labeled asset given its asset ID if it exists and matches the type.
This can be used to get the asset from its handle since &Handle implements
Into<AssetId<B>>.
Sourcepub fn get_erased_labeled_by_id(
&self,
id: impl Into<UntypedAssetId>,
) -> Option<&ErasedLoadedAsset>
pub fn get_erased_labeled_by_id( &self, id: impl Into<UntypedAssetId>, ) -> Option<&ErasedLoadedAsset>
Returns the type-erased labeled asset given its asset ID if it exists.
This can be used to get the asset from its handle since &UntypedHandle implements
Into<UntypedAssetId>.
Sourcepub fn get_untyped_handle<Q>(&self, label: &Q) -> Option<UntypedHandle>
pub fn get_untyped_handle<Q>(&self, label: &Q) -> Option<UntypedHandle>
Returns the UntypedHandle of the labeled asset with the provided ‘label’, if it exists.
Sourcepub fn get_handle<Q, B>(&self, label: &Q) -> Option<Handle<B>>
pub fn get_handle<Q, B>(&self, label: &Q) -> Option<Handle<B>>
Returns the Handle of the labeled asset with the provided ‘label’, if it exists and is an asset of type B
Sourcepub fn insert_labeled(
&mut self,
label: impl Into<CowArc<'static, str>>,
handle: impl Into<UntypedHandle>,
asset: impl Into<ErasedLoadedAsset>,
)
pub fn insert_labeled( &mut self, label: impl Into<CowArc<'static, str>>, handle: impl Into<UntypedHandle>, asset: impl Into<ErasedLoadedAsset>, )
Adds asset as a labeled sub asset using label and handle
Sourcepub fn iter_labels(&self) -> impl Iterator<Item = &str>
pub fn iter_labels(&self) -> impl Iterator<Item = &str>
Iterate over all labels for “labeled assets” in the loaded asset